using Frontend.Assets;
using Microsoft.EntityFrameworkCore;

namespace Frontend.AssetStores;

public class PotatoStorage(DbContextOptions<PotatoStorage> options) : DbContext(options)
{
    public required DbSet<PotatoTransaction> Transactions { get; set; }

    public async Task AddPotatoes(PotatoTransaction transaction)
    {
        await Transactions.AddAsync(transaction);
        await SaveChangesAsync();
    }

    public async Task<PotatoTransaction> RemovePotatoes(double weight)
    {
        var maxRemovableWeight = SupplyWeight();
    
        var removingWeight = Math.Min(maxRemovableWeight, weight);
        var newTransaction = new PotatoTransaction
        {
            Weight = -removingWeight,
        };
        await Transactions.AddAsync(newTransaction);
        await SaveChangesAsync();
        return newTransaction;
    }

    public double SupplyWeight()
    {
        return Transactions.Sum(p => p.Weight);
    }
}
