using System.Diagnostics.Metrics;
using Frontend.Configuration;
using Frontend.Metrics;
using Nethereum.Web3;
using Nethereum.Web3.Accounts;

namespace Frontend.BackgroundServices;

public class RebalanceService : BackgroundService
{

    private readonly ILogger<RebalanceService> _logger;
    private readonly TimeSpan _interval = TimeSpan.FromSeconds(10);
    private int startUpDelayCycles = 6;
    private readonly Rebalancer _rebalancer;

    public RebalanceService(
        Rebalancer rebalancer,
        ILogger<RebalanceService> logger
    )
    {
        _logger = logger;
        _rebalancer = rebalancer;
    }
    protected async override Task ExecuteAsync(CancellationToken stoppingToken)
    {
        while (!stoppingToken.IsCancellationRequested)
        {
            if (startUpDelayCycles > 0)
            {
                _logger.LogInformation("RebalanceService is waiting to start. remaining cycles: {startUpDelayCycles}", startUpDelayCycles);
                startUpDelayCycles--;
            }
            else
            {
                _logger.LogInformation("Rebalancer: EnsureCoinSupplyMatchesRwaSupplyAsync is running at {time}", DateTime.Now);
                await _rebalancer.EnsureCoinSupplyMatchesRwaSupplyAsync();
                _logger.LogInformation("Rebalancer: MaintainLiquidReservesAsync is running at {time}", DateTime.Now);
                await _rebalancer.MaintainLiquidReservesAsync();
                _logger.LogInformation("Rebalancer: MaintainPoolAsync is running at {time}", DateTime.Now);
                await _rebalancer.MaintainPoolAsync();
            }
            await Task.Delay(_interval, stoppingToken);
        }
    }
}