using System.Diagnostics.Metrics;
using Frontend.Configuration;
using Nethereum.Web3;

namespace Frontend.Metrics;

public class Erc20TokenMetrics
{
    private readonly IMeterFactory _meterFactory;
    private readonly TokenClient _rocTokenClient;
    private ObservableGauge<double>? _totalSupplyGauge;

    public Erc20TokenMetrics(IMeterFactory meterFactory,Web3 web3, ChainSettings chainSettings)
    {
        _meterFactory = meterFactory;
        _rocTokenClient = new(web3,chainSettings.TokenAddress);
    }

    public void CreateMetrics()
    {
        var meter = _meterFactory.Create("RoestiCoin");
        _totalSupplyGauge = meter.CreateObservableGauge("RoestiCoin.Supply.Total", () => GetTotalSupply(_rocTokenClient), unit: "ROC");
    
    }

    private double GetTotalSupply(TokenClient client)
    {
        var totalSupply = client.TotalSupply();
        totalSupply.Wait();
        return (double)totalSupply.Result;
    }
    
}