using System;
using System.Net.Http;
using System.Threading.Tasks;
using Newtonsoft.Json.Linq;

namespace Frontend;
public class PrometheusClient
{
    private readonly HttpClient _httpClient;
    private readonly string _prometheusBaseUrl;

    public PrometheusClient(string prometheusBaseUrl)
    {
        _httpClient = new HttpClient();
        _prometheusBaseUrl = prometheusBaseUrl;
    }

    public async Task<double> QueryMetricAsync(string metricName)
    {
        var queryUrl = $"{_prometheusBaseUrl}/api/v1/query?query={metricName}";
        var response = await _httpClient.GetAsync(queryUrl);

        if (!response.IsSuccessStatusCode)
        {
            throw new Exception($"Error querying Prometheus: {response.ReasonPhrase}");
        }

        var content = await response.Content.ReadAsStringAsync();
        var json = JObject.Parse(content);

        if (json["status"]!.ToString() != "success")
        {
            throw new Exception($"Error querying Prometheus: {json["error"]}");
        }

        var result = json["data"]!["result"]!;
        if (result.HasValues)
        {
            var value = result[0]!["value"]![1]!.ToString();
            return double.Parse(value);
        }

        throw new Exception("Metric not found");
    }
}